@@ -46,8 +46,10 @@ will show the list of files changed.
 #include <sys/wait.h>
 #include <string.h>
 #include <unistd.h>
-#include "parameter.h"
+
+#include "cowbuilder_util.h"
 #include "ilist.h"
+#include "parameter.h"
 
 const char* ilist_PRGNAME="cowbuilder";
 
@@ -220,7 +222,22 @@ static int cpbuilder_internal_cowcopy(const struct pbuilderconfig* pc)
  */
 static int cpbuilder_internal_cleancow(const struct pbuilderconfig* pc)
 {
+  /*
+   * A directory bind-mounted into pc->buildplace, will be cleaned out
+   * by rmrf() To avoid that potential disaster we want to detect if
+   * there's something mounted under the chroot before running the
+   * cleanup procedure.
+   */
+
+  char* canonicalized_buildplace = strdupa(pc->buildplace);
+
   printf(" -> Cleaning COW directory\n");
+
+  canonicalize_doubleslash(pc->buildplace, canonicalized_buildplace);
+  if (check_mountpoint(canonicalized_buildplace)) {
+    return 1;
+  }
+
   if (0!=rmrf(pc->buildplace))
     return 1;
   return 0;
