@@ -8,11 +8,14 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include "ilist.h"
+
 const char* ilist_PRGNAME="cowdancer-ilistdump";
 
 int main(int argc, char** argv)
 {
   struct ilist_struct s;
+  struct ilist_header h;
+
   FILE*f;
   
   if (argc != 2)
@@ -34,6 +37,16 @@ int main(int argc, char** argv)
       return 1;
     }
   
+  fread(&h, sizeof(struct ilist_header), 1, f);
+  fprintf(stderr, 
+	  "Signature: %x (expect %x)\n"
+	  "Revision: %i (expect %i)\n"
+	  "Struct size: %i\n\n",
+	  h.ilistsig, ILISTSIG, 
+	  h.revision, ILISTREVISION, 
+	  h.ilist_struct_size
+	  );
+  
   while(fread(&s, sizeof(struct ilist_struct), 1, f))
     {
       printf ("%li %li\n", (long)s.dev, (long)s.inode);
