@@ -43,7 +43,7 @@ static long ilist_len=0;
 /*
    verify the header content
  */
-int verify_ilist_header(struct ilist_header header)
+static int verify_ilist_header(struct ilist_header header)
 {
   if (header.revision != ILISTREVISION ||
       header.ilistsig != ILISTSIG ||
@@ -594,7 +594,7 @@ int chown(const char* s, uid_t u, gid_t g)
  * @return 1 on failure, 0 on success
  *
  */
-int check_fd_inode_and_warn(int fd, const char* operation)
+static int check_fd_inode_and_warn(int fd, const char* operation)
 {
   struct stat buf;
   struct ilist_struct search_target;
