@@ -1,6 +1,6 @@
 /*BINFMTC:
  *  fork/exec helper for pbuilder.
- *  Copyright (C) 2007-2008 Junichi Uekawa
+ *  Copyright (C) 2007-2009 Junichi Uekawa
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 
 /*
   execvp that does fork.
-  
+
   @return < 0 for failure, exit code for other cases.
  */
 int forkexecvp (char *const argv[])
@@ -36,32 +36,38 @@ int forkexecvp (char *const argv[])
   int ret;
   pid_t pid;
   int status;
-  
+
   /* DEBUG: */
   {
     int i=0;
+    printf("  forking: ");
+
     while(argv[i])
       {
-	//printf("DEBUG: %i: %s\n", i, argv[i]);
+	printf("%s ", argv[i]);
 	i++;
       }
+    printf("\n");
   }
 
+  fflush(NULL);
+
   switch(pid=fork())
     {
     case 0:
       execvp(argv[0], (char*const*)argv);
-      perror("cowbuilder: execvp");
+      perror("execvp");
+      fprintf(stderr, "Could not execute %s\n", argv[0]);
       exit(EXIT_FAILURE);
     case -1:
       /* error condition in fork(); something is really wrong */
-      perror("cowbuilder: fork");
+      perror("fork");
       return -1;
     default:
       /* parent process, waiting for termination */
       if (-1==waitpid(pid, &status, 0))
 	{
-	  perror("cowbuilder: waitpid");
+	  perror("waitpid");
 	  fprintf(stderr, "unexpected waitpid error when waiting for process %i with status %x\n",
 		  pid, status);
 	  return -1;
@@ -78,10 +84,10 @@ int forkexecvp (char *const argv[])
 
 /*
   execlp that does fork.
-  
+
   NULL-terminated list of parameters.
 
-  cf. execl from FreeBSD sources, and glibc posix/execl.c, 
+  cf. execl from FreeBSD sources, and glibc posix/execl.c,
   and cygwin exec.cc
 
   @return < 0 for failure, exit code for other cases.
@@ -98,24 +104,34 @@ forkexeclp (const char *path, const char *arg0, ...)
   va_start(args, arg0);
   argv[0] = arg0;
   i = 1;
+
+  printf("  forking: %s ", argv[0]);/* debug message */
+
   do
     {
       argv[i] = va_arg(args, const char *);
-      
-      if ( i >= 1023 ) 
+      if (argv[i])
+	printf("%s ", argv[i]);   /* debug message */
+
+      if ( i >= 1023 )
 	{
 	  return -1;
 	}
-      
+
     }
   while (argv[i++] != NULL);
   va_end (args);
 
+  printf("\n");			/* debug message */
+
+  fflush(NULL);
+
   switch(pid=fork())
     {
     case 0:
       execvp(path, (char*const*)argv);
       perror("pbuilder: execlp");
+      fprintf(stderr, "Could not execute %s\n", path);
       exit(EXIT_FAILURE);
     case -1:
       /* error condition in fork(); something is really wrong */
@@ -125,7 +141,7 @@ forkexeclp (const char *path, const char *arg0, ...)
       /* parent process, waiting for termination */
       if (-1==waitpid(pid, &status, 0))
 	{
-	  perror("cowbuilder: waitpid");
+	  perror("waitpid");
 	  return -1;
 	}
       if (!WIFEXITED(status))
